.. highlight:: shell

Installation
**********************

gabrieltool Python Library
---------------------------

From PyPI

.. code-block:: console

    $ pip install -U gabrieltool

From Source

.. code-block:: console

    $ git clone https://github.com/cmusatyalab/OpenWorkflow.git
    $ cd OpenWorkflow/
    $ python setup.py install

FSM Web Editor
---------------------------

Visit `<https://cmusatyalab.github.io/OpenWorkflow>`_. Or You can download its
build from the repo's `gh-pages branch 
<https://github.com/cmusatyalab/OpenWorkflow/archive/gh-pages.zip>`_ and open
the downloaded index.html.